@@ -1,13 +1,13 @@
-// 	$Id: BoolNetObserverSwarm.h,v 1.1.1.1 1998/01/08 00:56:13 alex Exp $	
-
-#import <swarmobject.h>
+// 	$Id: BoolNetObserverSwarm.h,v 1.3 1998/02/27 22:01:10 mgd Exp $	
+#import <objectbase.h>
 #import <activity.h>
 #import <collections.h>
-#import <simtools.h>
 #import <analysis.h>
+#import <simtoolsgui/GUISwarm.h>
 #import "BoolNetModelSwarm.h"
 
-@interface BoolNetObserverSwarm : GUISwarm {
+@interface BoolNetObserverSwarm: GUISwarm
+{
   int displayFrequency;
   int interactiveGraph;
   id displayActions;	
